@@ -8,14 +8,7 @@ Date: 2020-07-15
 
 Author: Lorenzo Coacci
 """
-
-# LEGEND
-# * * * * * * * * * * * = TITLE/High priority text
-# + + + + + = SUBTITLE/Medium priority text
-# - - = SUBSUBTITLE/Low priority text
-# = normal comment/informative text
-
-# * * * * * * * * * * LIBRARIES * * * * * * * * * *
+# + + + + + Libraries + + + + +
 # to manage data - pandas
 import pandas as pd
 # to manage speech recognition (speech 2 text)
@@ -26,91 +19,15 @@ import pyttsx3
 import time
 # to play sounds
 from playsound import playsound
-# optional modules
-try:
-    from datetime import datetime
-    # to manage traceback
-    import traceback
-    # to manage colored text
-    from termcolor import colored as col
-except Exception as e:
-    print("Import optional modules error, check code")
-# * * * * * * * * * * LIBRARIES * * * * * * * * * *
+# for log funcs
+from golog import (
+    error_print, warning_print,
+    ERROR_COLOR, info_print
+)
+# + + + + + Libraries + + + + +
 
 
-# * * * * * * * * * * FUNCTIONS * * * * * * * * * *
-def label_print(msg, num_of_new_lines=0, num_of_tabs=0,
-                color=None, label="LABEL: ", timestamp=True,
-                exception=None):
-    """VOID : Print out a labeled message with a nice format"""
-    # number of new lines before text
-    if timestamp:
-        label = '[' + str(datetime.now()) + '] ' + label
-
-    if num_of_new_lines > 0:
-        for _ in range(num_of_new_lines):
-            print("\n")
-    if num_of_tabs > 0:
-        for _ in range(num_of_tabs):
-            print("\t")
-    # print labeled message
-    msg = str(msg)
-    # traceback?
-    if exception is not None:
-        msg += ", EXCEPTION -> {}, TRACEBACK -> {}".format(str(exception), str(traceback.format_exc()))
-    if color is None:
-        if msg is None:
-            print(None)
-        else:
-            print(label + msg)
-    else:
-        try:
-            if msg is None:
-                print(None)
-            else:
-                print(col(label + msg, color))
-        except Exception as e:
-            if msg is None:
-                print(None)
-            else:
-                print(label + msg)
-
-
-def error_print(msg, num_of_new_lines=0, num_of_tabs=0,
-                color=ERROR_COLOR, error_label="* * * ERROR * * * : ",
-                timestamp=True, exception=None):
-    """VOID : Print out an error message with a nice format"""
-    # error print
-    label_print(msg, num_of_new_lines=num_of_new_lines,
-                num_of_tabs=num_of_tabs, color=color,
-                label=error_label, timestamp=timestamp,
-                exception=exception)
-
-
-def warning_print(msg, num_of_new_lines=0, num_of_tabs=0,
-                  color=WARNING_COLOR, warning_label="* WARNING * : ",
-                  timestamp=True, exception=None):
-    """VOID : Print out a warning message with a nice format"""
-    # warning print
-    label_print(msg, num_of_new_lines=num_of_new_lines,
-                num_of_tabs=num_of_tabs, color=color,
-                label=warning_label, timestamp=timestamp,
-                exception=exception)
-
-
-def info_print(msg, num_of_new_lines=0, num_of_tabs=0,
-               color=INFO_COLOR, info_label="INFO : ",
-               timestamp=True, exception=None):
-    """VOID : Print out an info message with a nice format"""
-    # info print
-    label_print(msg, num_of_new_lines=num_of_new_lines,
-                num_of_tabs=num_of_tabs, color=color,
-                label=info_label, timestamp=timestamp,
-                exception=exception)
-# * * * * * * * * * * FUNCTIONS * * * * * * * * * *
-
-
-# * * * * * * * * * * CLASSES * * * * * * * * * *
+# + + + + + Classes + + + + +
 class Iago():
     """
     Iago : a Python Speaking Assistant
@@ -912,4 +829,4 @@ class Iago():
             if show_debug:
                 error_print("Cannot get stop_string", exception=e)
             return {"status": False, "error": "Cannot get stop_string because -> {}".format(str(e)), "value": None}
-# * * * * * * * * * * CLASSES * * * * * * * * * *
+# + + + + + Classes + + + + +
